# viz
* `helpers_graphing` is a set of helpful import statements that converts the environment to being similar to a Matlab coding environment. It also imports a few custom scripts from:
* `viz` includes small helpful scripts to change figure sizes and a few longer scripts like `streamgraph` and `logfit`
* `etl` has a few small scripts to help with data formats and time zones and fancy function for smoothing data `nan_smooth`
* `histogram_utils` includes awesome functions for making nice 1 and 2d histograms

To make use of everything at once run:
```
from helpers_graphing import *
```
